@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.051'; # VERSION
+our $VERSION = '0.052'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -52,7 +52,7 @@ App::Pinto::Command::add - add local archives to the repository
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 SYNOPSIS
 
@@ -85,9 +85,9 @@ or ';') will be ignored.
 =item --author NAME
 
 Set the identity of the distribution author.  The C<NAME> must be
-alphanumeric characters (no spaces) and will be forced to uppercase.
-Defaults to the C<user> specified in your C<~/.pause> configuration
-file (if such file exists).  Otherwise, defaults to your current login
+alphanumeric characters plus hyphens and underscores.  Defaults to
+the uppercased C<user> specified in your C<~/.pause> configuration
+file if such file exists.  Otherwise, defaults to your current login
 username.
 
 =item --dryrun
