@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.051'; # VERSION
+our $VERSION = '0.052'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -66,7 +66,7 @@ App::Pinto::Command::copy - create a new stack by copying another
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 SYNOPSIS
 
@@ -86,8 +86,8 @@ properties after it has been created.
 =head1 COMMAND ARGUMENTS
 
 The two required arguments are the name of the source and target
-stacks.  Stack names must be alphanumeric (including "-" or "_") and
-will be forced to lowercase.
+stacks.  Stack names must be alphanumeric plus hyphens and underscores,
+and are not case-sensitive.
 
 =head1 COMMAND OPTIONS
 
