@@ -13,7 +13,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.051'; # VERSION
+our $VERSION = '0.052'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -84,7 +84,7 @@ App::Pinto::Command::init - create a new repository
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 SYNOPSIS
 
@@ -128,12 +128,13 @@ option.  Repositories that appear earlier in the list have priority
 over those that appear later.  See L<Pinto::Manual> for more
 information about using multiple source repositories.
 
-=item --stack-NAME
+=item --stack=NAME
 
 =item -s NAME
 
-The name of the inital stack.  Stack names must be alphanumeric and
-will be force to lowercase.  Defalts to 'init'.
+The name of the inital stack.  Stack names must be alphanumeric
+plus hyphens and undercores, and are not case sensitive.  Defalts
+to 'init'.
 
 =back
 
